ChuckerHttpLoggingInterceptor class

Logs http request and response data

Constructors

ChuckerHttpLoggingInterceptor()
Creates an interceptor that prints HTTP traffic to the provided Logger.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

intercept<BodyType>(Chain<BodyType> chain) → FutureOr<Response<BodyType>>
Intercepts the chain, logs its request/response pair, and forwards it.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited